package Unicode::ICU::Collate;
use strict; use warnings;
use base qw(DynaLoader);
our $VERSION = 0.01;
bootstrap Unicode::ICU::Collate 0.01;

1;

=pod

=head1 NAME

Unicode::ICU::Collate - ICU Unicode Collation services

=head1 DESCRIPTION

This library wraps (part of) ICU's Unicode Collation Services for perl.

ICU is a mature C, C++ and Java library providing Unicode and Globalization
support. ICU is also used by L<parrot|http://www.parrotcode.org>.

Collation is the sort rules - for example, the letter C<ä> is sorted between
C<a> and C<b> in German, but as a extra letter after C<z>  in Swedish.

=head1 METHODS/FUNCTIONS

=head2 OO Interface

=head3 new

Constructor.

Returns a collation object. Requires the locale as only parameter.

Note that the locale is a ICU locale, not your system's or perl's (or a POSIX)
locale. See http://www.icu-project.org/userguide/locale.html if in question.

=head3 compare

Compares two strings using the collation object's locale.

=head3 sortkey

Obtain a sort key for a string. If you need to compare large numbers of
records repeatedly, it might be more efficient to obtain a sortkey for
every element and sort the sortkeys instead.

Note, however, that this is almost certainly slower for one-time searches:

=head2 Procedural interface

=head3 icu_strcoll

 my $strcmp = Unicode::ICU::Collate::icu_strcoll($locale, $a, $b);

Compares two strings using the locale given. The locale is a ICU locale
string.

Note that this function is a magnitude slower than the OO interface - it's
only here for convenience and testing.

=head1 BUGS AND LIMITATIONS

Many.

=head1 ACKNOWLEDGEMENTS

This library was largely inspired by L<Unicode::Transliterate|Unicode::Transliterate>
by Jean-Michel Hiver, which also uses ICU.

The ICU library does the actual work: See http://www.icu-project.org/

=head1 LICENSE AND COPYRIGHT

Copyright 2008 Martin Kutter.

This library is free software. You may distribute/modify it under
the same terms as perl itself

=head1 AUTHOR

Martin Kutter E<lt>martin.kutter fen-net.deE<gt>

=head1 REPOSITORY INFORMATION

 $Rev: 480 $
 $LastChangedBy: kutterma $
 $Id: Collate.pm 480 2008-06-01 21:24:36Z kutterma $
 $HeadURL: http://svn.hyper-framework.org/Hyper/Unicode-ICU/trunk/lib/Unicode/ICU/Collate.pm $

=cut